@@ -14,7 +14,7 @@ class TerminateInstancesAction(BaseAction):
 
         parser.add_argument('-i', '--instances', dest='instances',
                 action='store', type=str, default='',
-                help='The comma separated IDs of instances you want to terminate.')
+                help='the comma separated IDs of instances you want to terminate.')
 
         return parser
 
@@ -22,7 +22,7 @@ class TerminateInstancesAction(BaseAction):
     def build_directive(cls, options):
         instances = explode_array(options.instances)
         if not instances:
-            print 'error:instance_id should be specified'
+            print 'error: [instances] should be specified'
             return None
 
         return {'instances': instances}
